@@ -1,5 +1,6 @@
 
 import inspect
+from os.path import abspath, dirname, join
 
 from .helpers import list_of
 from .utils import camelToSnake
@@ -199,35 +200,46 @@ class GlobalsObjectProxy(dict):
         
 
 
-def parse_dsl_file(filename, obj):
+def parse_dsl_file(filename, obj, include_attr_name=None):
     '''
         Given a file of code formatted in the DSL that corresponds to the 
         given object, parse the content and store it in the object.
     
         :param filename:  File to read from
         :param cls: Class or object
+        :param include_attr_name: Name to use in DSL for function that
+                   includes other pydsl files. Defaults to 'include_file'.
     '''
     
     with open(filename, 'r') as fp:
-        return parse_dsl(fp.read(), obj, filename)
+        return parse_dsl(fp.read(), obj, filename, include_attr_name)
 
 
-def parse_dsl(string, obj, filename=None):
+def parse_dsl(string, obj, filename=None, include_attr_name=None):
     '''
         Given a bit of code formatted in the DSL that corresponds to the 
         given object, parse the content and store it in the object.
     
         :param string: String of python code to interpret
         :param cls: Class or object
+        :param include_attr_name: Name to use in DSL for function that
+                   includes other pydsl files. Defaults to 'include_file'
+                   include_file will only be added to DSL files that have
+                   an associated filename
     '''
     
     if inspect.isclass(obj):
         obj = obj()
+        
+    if include_attr_name is None:
+        include_attr_name = 'include_file'
     
     # create a wrapper around the object
     dsl_globals = GlobalsObjectProxy(obj, filename)
     
-    if filename is None:
+    if filename is not None:
+        dsl_globals[include_attr_name] = lambda f: parse_dsl_file(abspath(join(dirname(filename),f)), obj, include_attr_name)
+    else:
         filename = '<string>'
     
     code = compile(string, filename, 'exec')
