@@ -4,6 +4,8 @@
 #
 
 import re
+from functools import wraps
+import warnings
 
 _underscorer1 = re.compile(r'(.)([A-Z][a-z]+)')
 _underscorer2 = re.compile('([a-z0-9])([A-Z])')
@@ -16,3 +18,10 @@ def camelToSnake(s):
     subbed = _underscorer1.sub(r'\1_\2', s)
     return _underscorer2.sub(r'\1_\2', subbed).lower()
 
+
+def deprecated(func):
+    @wraps(func)
+    def wrapper(*args, **kwargs):
+        warnings.warn("deprecated", DeprecationWarning, stacklevel=2)
+        return func(*args, **kwargs)
+    return wrapper
